# Xircuits Project Templates List

Xircuits Project Templates are repositories that uses Xircuits for their specific use case. Unlike Xircuits libraries that are framework focused and typically only contain Xircuits components, project templates are more use case oriented. Each repository contain all the necessary Xircuits components and files needed to start a project.

## How to Use
As a user, all you need is to clone the repository and run their `setup.sh` scripts. Don't forget to read their readmes.

```
$ git clone https://github.com/XpressAI/xircuits-project-template-name
$ cd xircuits-project-template-name
$ bash setup.sh
```

## List of Open Source Project Templates
The following are some open source Xircuits template projects by our developers and open source contributors. If you would like to showcase your own Xircuits project here, give this page a PR!

<div align="center">


| Use Case | Author |
| -------- | ------ |
| [Image Classification](https://github.com/XpressAI/x-template-image_classification) | [MansourAlawi](https://github.com/mansouralawi) | 
| [Iris Classification](https://github.com/XpressAI/x-template-iris_classification) |  [ThurgaShri](https://github.com/ThurgaShri) |
| [Handwritten Digit Recognition](https://github.com/XpressAI/x-template-handwritten_digit_recognition) |  [ThurgaShri](https://github.com/ThurgaShri)
| [Speech Recognition](https://github.com/XpressAI/x-template-speech_recognition) | [ThurgaShri](https://github.com/ThurgaShri) |
| [Face Detection](https://github.com/XpressAI/x-template-face_detection) | [annabelle1217](https://github.com/annabelle1217) |
| [Chatbot](https://github.com/XpressAI/x-template-chatbot) | [annabelle1217](https://github.com/annabelle1217) |
| [Semantic Segmentation](https://github.com/XpressAI/x-template-semantic_segmentation) | [quietrex](https://github.com/quietrex)

</div>

For more information, checkout our [project template documentation page!](https://xircuits.io/docs/project-template/). Learn [how to use Xircuits project templates](https://xircuits.io/docs/main/tutorials/running-a-xircuits-project-template) or [how to create your own project from our template](https://xircuits.io/docs/main/developer-guide/creating-a-xircuits-project-template).
